@@ -12,15 +12,12 @@
 #'
 #' @param countries A character vector specifying country names of interest.
 #' Used to filter the data.
-#' @param country `r lifecycle::badge("deprecated")` A character string
-#'  specifying a country to filter for.
 #' @param source A character string specifying the data source (not case
 #'  dependent). Defaults to WHO (the World Health Organisation). See
 #' `get_available_datasets("national")` for all options.
 #' @return A tibble with data related to cases, deaths, hospitalisations,
 #'  recoveries and testing.
 #' @inheritParams get_regional_data
-#' @importFrom lifecycle deprecated is_present deprecate_warn
 #' @family interface
 #' @seealso [WHO()], [ECDC()], [JHU()], [Google()]
 #' @export
@@ -54,16 +51,7 @@
 #' }
 get_national_data <- function(countries, source = "who", level = "1", totals = FALSE,
                               steps = FALSE, class = FALSE, verbose = TRUE,
-                              country = deprecated(),
                               ...) {
-  if (is_present(country)) {
-    deprecate_warn(
-      "0.9.0",
-      "covidregionaldata::get_national_data(country = )",
-      "covidregionaldata::get_national_data(countries = )"
-    )
-    countries <- country
-  }
 
   # check data availability and initiate country class if available
   nation_class <- initialise_dataclass(
