@@ -7,7 +7,7 @@
 #' @return A tibble with relevant NA columns added
 #' @family compulsory_processing
 #' @concept compulsory_processing
-#' @importFrom tibble tibble add_column
+#' @importFrom dplyr mutate
 #' @importFrom rlang !!!
 add_extra_na_cols <- function(data) {
   expected_col_names <- c(
@@ -17,7 +17,7 @@ add_extra_na_cols <- function(data) {
 
   new_cols <- rep(list(NA_real_), length(expected_col_names))
   names(new_cols) <- expected_col_names
-  data <- add_column(
+  data <- mutate(
     data,
     !!!new_cols[!(names(new_cols) %in% names(data))]
   )
@@ -50,18 +50,22 @@ set_negative_values_to_zero <- function(data) {
 #' @return A tibble with rows of NAs added.
 #' @family compulsory_processing
 #' @concept compulsory_processing
-#' @importFrom tibble tibble
 #' @importFrom tidyr complete full_seq nesting
-#' @importFrom tidyselect starts_with
+#' @importFrom dplyr starts_with group_by ungroup group_vars
 #' @importFrom rlang !!! syms
 fill_empty_dates_with_na <- function(data) {
   regions <- select(data, starts_with("level_")) %>%
     names()
+
+  groups <- group_vars(data)
+
   data <- data %>%
+    ungroup() %>%
     complete(
       date = full_seq(data$date, period = 1),
       nesting(!!!syms(regions))
-    )
+    ) %>%
+    group_by(across(.cols = all_of(groups)))
   return(data)
 }
 
@@ -76,7 +80,7 @@ fill_empty_dates_with_na <- function(data) {
 #' @family compulsory_processing
 #' @concept compulsory_processing
 #' @importFrom tidyr fill
-#' @importFrom tidyselect all_of
+#' @importFrom dplyr all_of
 complete_cumulative_columns <- function(data) {
   cumulative_col_names <- c(
     "deaths_total", "cases_total", "recovered_total",
@@ -99,11 +103,9 @@ complete_cumulative_columns <- function(data) {
 #' @return A data frame with extra columns if required
 #' @family compulsory_processing
 #' @concept compulsory_processing
-#' @importFrom dplyr mutate group_by_at arrange vars starts_with lag
+#' @importFrom dplyr mutate group_by_at arrange vars starts_with lag ends_with
 #' @importFrom purrr walk2
 #' @importFrom tidyr replace_na
-#' @importFrom tidyselect ends_with
-#' @importFrom tibble tibble
 #' @importFrom rlang !! :=
 calculate_columns_from_existing_data <- function(data) {
   possible_counts <- c("cases", "deaths", "hosp", "recovered", "tested")
@@ -150,7 +152,6 @@ calculate_columns_from_existing_data <- function(data) {
 #' @param data A data table
 #' @return A data table, totalled up
 #' @importFrom dplyr left_join group_by summarise select arrange
-#' @importFrom tibble tibble
 #' @family optional_processing
 #' @concept optional_processing
 totalise_data <- function(data) {
@@ -224,9 +225,8 @@ run_optional_processing_fns <- function(data, process_fns) {
 #' @concept utility
 #' @family processing
 #' @importFrom dplyr do group_by_at across ungroup select everything arrange
-#' @importFrom dplyr rename
+#' @importFrom dplyr rename all_of
 #' @importFrom tidyr drop_na
-#' @importFrom tidyselect all_of
 #' @importFrom rlang !!!
 process_internal <- function(clean_data, level, group_vars,
                              totals = FALSE, localise = TRUE,
@@ -263,9 +263,9 @@ process_internal <- function(clean_data, level, group_vars,
           "hosp_new", "hosp_total", "tested_new", "tested_total"
         )),
         everything()
-      ) %>%
-      arrange(.data$date, all_of(group_vars_standard[1]))
+      )
   }
+
   dat <- ungroup(dat)
 
   if (localise) {
