@@ -114,7 +114,7 @@ test_that("DataClass returns a summary", {
     names(sum),
     c(
       "origin", "class", "level_1_region", "level_2_region", "level_3_region",
-      "type", "data_urls", "source_data_cols"
+      "type", "data_urls", "source_data_cols", "source_text", "source_url"
     )
   )
   expect_true(sum$class[1] == "D")
