@@ -1,4 +1,4 @@
-check_fields <- function(field, region_class, country) {
+check_mandatory_fields <- function(field, region_class, country) {
   test_that(
     paste(
       "Expect", field, "is in",
@@ -10,20 +10,37 @@ check_fields <- function(field, region_class, country) {
   )
 }
 
+check_either_or_fields <- function(region_class, country) {
+  test_that(
+    paste(
+      "Expect",
+      country,
+      "has one of common_data_urls or level_data_urls"
+    ),
+    {
+      expect_true(
+        "common_data_urls" %in% names(region_class$public_fields) |
+          "level_data_urls" %in% names(region_class$public_fields)
+      )
+    }
+  )
+}
+
 check_country_class <- function(country) {
   region_class <- get(country)
   expected_public_fields <- c(
     "origin", "supported_levels",
     "supported_region_names",
     "supported_region_codes",
-    "common_data_urls", "source_data_cols"
+    "source_data_cols"
   )
   purrr::walk(
     expected_public_fields,
-    check_fields,
+    check_mandatory_fields,
     region_class,
     country
   )
+  check_either_or_fields(region_class, country)
 }
 
 # run tests
